<?php
/*
 * @package Zodiac Astrology
 */

function zodiacastrology_admin_enqueue_scripts() {
	wp_enqueue_style( 'zodiac-astrology-admin-style', esc_url( get_template_directory_uri() ).'/css/addon.css' );
}
add_action( 'admin_enqueue_scripts', 'zodiacastrology_admin_enqueue_scripts' );

add_action('after_switch_theme', 'zodiacastrology_options');

function zodiacastrology_options () {
	global $pagenow;
	if( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) && current_user_can( 'manage_options' ) ) {
		wp_redirect( admin_url( 'themes.php?page=zodiac-astrology' ) );
		exit;
	}
}

function zodiacastrology_theme_info_menu_link() {

	$theme = wp_get_theme();
	add_theme_page(
		sprintf( esc_html__( 'Welcome to Zodiac Astrology', 'zodiac-astrology' ), $theme->display( 'Name' ), $theme->display( 'Version' ) ),
		esc_html__( 'Theme Info', 'zodiac-astrology' ),'edit_theme_options','zodiac-astrology','zodiacastrology_theme_info_page'
	);
}
add_action( 'admin_menu', 'zodiacastrology_theme_info_menu_link' );

function zodiacastrology_theme_info_page() {

	$theme = wp_get_theme();
	?>
<div class="wrap theme-info-wrap">
	<h1><?php printf( esc_html__( 'Welcome to Zodiac Astrology', 'zodiac-astrology' ), esc_html($theme->display( 'Name', 'zodiac-astrology'  )),esc_html($theme->display( 'Version', 'zodiac-astrology' ))); ?>
	</h1>
	<p class="theme-description">
	<?php esc_html_e( 'Do you want to configure this theme? Look no further, our easy-to-follow theme documentation will walk you through it.', 'zodiac-astrology' ); ?>
	</p>
	<hr>
	<div class="important-links clearfix">
		<p><strong><?php esc_html_e( 'Theme Links', 'zodiac-astrology' ); ?>:</strong>
			<a href="<?php echo esc_url( ZODIACASTROLOGY_THEME_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Theme Page', 'zodiac-astrology' ); ?></a>
			<a href="<?php echo esc_url( ZODIACASTROLOGY_SUPPORT ); ?>" target="_blank"><?php esc_html_e( 'Contact Us', 'zodiac-astrology' ); ?></a>
			<a href="<?php echo esc_url( ZODIACASTROLOGY_REVIEW ); ?>" target="_blank"><?php esc_html_e( 'Rate This Theme', 'zodiac-astrology' ); ?></a>
			<a href="<?php echo esc_url( ZODIACASTROLOGY_PRO_DEMO ); ?>" target="_blank"><?php esc_html_e( 'Premium Demo', 'zodiac-astrology' ); ?></a>
			<a href="<?php echo esc_url( ZODIACASTROLOGY_PREMIUM_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Go To Premium', 'zodiac-astrology' ); ?></a>
			<a href="<?php echo esc_url( ZODIACASTROLOGY_THEME_DOCUMENTATION ); ?>" target="_blank"><?php esc_html_e( 'Documentation', 'zodiac-astrology' ); ?></a>
		</p>
	</div>
	<hr>
	<div id="getting-started">
		<h3><?php printf( esc_html__( 'Getting started with Zodiac Astrology', 'zodiac-astrology' ),
		esc_html($theme->display( 'Name', 'zodiac-astrology' ))); ?></h3>
		<div class="columns-wrapper clearfix">
			<div class="column column-half clearfix">
				<div class="section">
					<h4><?php esc_html_e( 'Theme Description', 'zodiac-astrology' ); ?></h4>
					<div class="theme-description-1"><?php echo esc_html($theme->display( 'Description' )); ?></div>
				</div>
			</div>
			<div class="column column-half clearfix">
				<img src="<?php echo esc_url( $theme->get_screenshot() ); ?>" alt=""/>
				<div class="section">
					<h4><?php esc_html_e( 'Theme Options', 'zodiac-astrology' ); ?></h4>
					<p class="about">
					<?php printf( esc_html__( 'Zodiac Astrology makes use of the Customizer for all theme settings. Click on "Customize Theme" to open the Customizer now.', 'zodiac-astrology' ),esc_html($theme->display( 'Name', 'zodiac-astrology' ))); ?></p>
					<p>
					<a href="<?php echo esc_attr(wp_customize_url()); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Customize Theme', 'zodiac-astrology' ); ?></a>
					<a href="<?php echo esc_url( ZODIACASTROLOGY_PREMIUM_PAGE ); ?>" target="_blank" class="button button-secondary premium-btn"><?php esc_html_e( 'Checkout Premium', 'zodiac-astrology' ); ?></a></p>
				</div>
			</div>
		</div>
	</div>
	<hr>
	<div id="theme-author">
	  <p><?php
		printf( esc_html__( 'Zodiac Astrology is proudly brought to you by %2$s. If you like this theme, rate it :)', 'zodiac-astrology' ),
			esc_html($theme->display( 'Name', 'zodiac-astrology' )),
			'<a target="_blank" href="' . esc_url( 'https://www.theclassictemplates.com/', 'zodiac-astrology' ) . '">classictemplate</a>',
			'<a target="_blank" href="' . esc_url( ZODIACASTROLOGY_REVIEW ) . '" title="' . esc_attr__( 'Rate it', 'zodiac-astrology' ) . '">' . esc_html_x( 'rate it', 'If you like this theme, rate it', 'zodiac-astrology' ) . '</a>'
		)
		?></p>
	</div>
</div>
<?php
}
